@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
- * Copyright © 2016-2018 The TokTok team.
+ * Copyright © 2016-2024 The TokTok team.
  * Copyright © 2013-2016 Tox Developers.
  */
 
@@ -14,7 +14,6 @@
 #include <stddef.h>
 #include <stdint.h>
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -46,8 +45,6 @@ extern "C" {
  *
  ******************************************************************************/
 
-
-
 /**
  * The size of the salt part of a pass-key.
  */
@@ -91,7 +88,6 @@ typedef enum Tox_Err_Key_Derivation {
 
 } Tox_Err_Key_Derivation;
 
-
 typedef enum Tox_Err_Encryption {
 
     /**
@@ -118,7 +114,6 @@ typedef enum Tox_Err_Encryption {
 
 } Tox_Err_Encryption;
 
-
 typedef enum Tox_Err_Decryption {
 
     /**
@@ -157,8 +152,6 @@ typedef enum Tox_Err_Decryption {
 
 } Tox_Err_Decryption;
 
-
-
 /*******************************************************************************
  *
  *                                BEGIN PART 1
@@ -169,14 +162,12 @@ typedef enum Tox_Err_Decryption {
  *
  ******************************************************************************/
 
-
-
 /**
  * Encrypts the given data with the given passphrase.
  *
- * The output array must be at least `plaintext_len + TOX_PASS_ENCRYPTION_EXTRA_LENGTH`
- * bytes long. This delegates to tox_pass_key_derive and
- * tox_pass_key_encrypt.
+ * The output array must be at least
+ * `plaintext_len + TOX_PASS_ENCRYPTION_EXTRA_LENGTH` bytes long. This delegates
+ * to tox_pass_key_derive and tox_pass_key_encrypt.
  *
  * @param plaintext A byte array of length `plaintext_len`.
  * @param plaintext_len The length of the plain text array. Bigger than 0.
@@ -186,26 +177,27 @@ typedef enum Tox_Err_Decryption {
  *
  * @return true on success.
  */
-bool tox_pass_encrypt(const uint8_t *plaintext, size_t plaintext_len, const uint8_t *passphrase, size_t passphrase_len,
-                      uint8_t *ciphertext, Tox_Err_Encryption *error);
+bool tox_pass_encrypt(const uint8_t plaintext[], size_t plaintext_len, const uint8_t passphrase[], size_t passphrase_len,
+                      uint8_t ciphertext[/*! plaintext_len + TOX_PASS_ENCRYPTION_EXTRA_LENGTH */], Tox_Err_Encryption *error);
 
 /**
  * Decrypts the given data with the given passphrase.
  *
- * The output array must be at least `ciphertext_len - TOX_PASS_ENCRYPTION_EXTRA_LENGTH`
- * bytes long. This delegates to tox_pass_key_decrypt.
+ * The output array must be at least
+ * `ciphertext_len - TOX_PASS_ENCRYPTION_EXTRA_LENGTH` bytes long. This
+ * delegates to tox_pass_key_decrypt.
  *
  * @param ciphertext A byte array of length `ciphertext_len`.
- * @param ciphertext_len The length of the cipher text array. At least TOX_PASS_ENCRYPTION_EXTRA_LENGTH.
+ * @param ciphertext_len The length of the cipher text array. At least
+ *   TOX_PASS_ENCRYPTION_EXTRA_LENGTH.
  * @param passphrase The user-provided password. Can be empty.
  * @param passphrase_len The length of the password.
  * @param plaintext The plain text array to write the decrypted data to.
  *
  * @return true on success.
  */
-bool tox_pass_decrypt(const uint8_t *ciphertext, size_t ciphertext_len, const uint8_t *passphrase,
-                      size_t passphrase_len, uint8_t *plaintext, Tox_Err_Decryption *error);
-
+bool tox_pass_decrypt(const uint8_t ciphertext[], size_t ciphertext_len, const uint8_t passphrase[],
+                      size_t passphrase_len, uint8_t plaintext[/*! ciphertext_len - TOX_PASS_ENCRYPTION_EXTRA_LENGTH */], Tox_Err_Decryption *error);
 
 /*******************************************************************************
  *
@@ -216,8 +208,6 @@ bool tox_pass_decrypt(const uint8_t *ciphertext, size_t ciphertext_len, const ui
  *
  ******************************************************************************/
 
-
-
 /**
  * This type represents a pass-key.
  *
@@ -227,7 +217,8 @@ bool tox_pass_decrypt(const uint8_t *ciphertext, size_t ciphertext_len, const ui
  * user-provided password.
  *
  * The Tox_Pass_Key structure is hidden in the implementation. It can be created
- * using tox_pass_key_derive or tox_pass_key_derive_with_salt and must be deallocated using tox_pass_key_free.
+ * using tox_pass_key_derive or tox_pass_key_derive_with_salt and must be
+ * deallocated using tox_pass_key_free.
  */
 #ifndef TOX_PASS_KEY_DEFINED
 #define TOX_PASS_KEY_DEFINED
@@ -255,8 +246,9 @@ void tox_pass_key_free(Tox_Pass_Key *key);
  *
  * @return new symmetric key on success, NULL on failure.
  */
-Tox_Pass_Key *tox_pass_key_derive(const uint8_t *passphrase, size_t passphrase_len,
-        Tox_Err_Key_Derivation *error);
+Tox_Pass_Key *tox_pass_key_derive(
+    const uint8_t passphrase[], size_t passphrase_len,
+    Tox_Err_Key_Derivation *error);
 
 /**
  * Same as above, except use the given salt for deterministic key derivation.
@@ -267,14 +259,16 @@ Tox_Pass_Key *tox_pass_key_derive(const uint8_t *passphrase, size_t passphrase_l
  *
  * @return new symmetric key on success, NULL on failure.
  */
-Tox_Pass_Key *tox_pass_key_derive_with_salt(const uint8_t *passphrase, size_t passphrase_len,
-        const uint8_t *salt, Tox_Err_Key_Derivation *error);
+Tox_Pass_Key *tox_pass_key_derive_with_salt(
+    const uint8_t passphrase[], size_t passphrase_len,
+    const uint8_t salt[TOX_PASS_SALT_LENGTH], Tox_Err_Key_Derivation *error);
 
 /**
- * Encrypt a plain text with a key produced by tox_pass_key_derive or tox_pass_key_derive_with_salt.
+ * Encrypt a plain text with a key produced by tox_pass_key_derive or
+ * tox_pass_key_derive_with_salt.
  *
- * The output array must be at least `plaintext_len + TOX_PASS_ENCRYPTION_EXTRA_LENGTH`
- * bytes long.
+ * The output array must be at least
+ * `plaintext_len + TOX_PASS_ENCRYPTION_EXTRA_LENGTH` bytes long.
  *
  * @param plaintext A byte array of length `plaintext_len`.
  * @param plaintext_len The length of the plain text array. Bigger than 0.
@@ -282,21 +276,22 @@ Tox_Pass_Key *tox_pass_key_derive_with_salt(const uint8_t *passphrase, size_t pa
  *
  * @return true on success.
  */
-bool tox_pass_key_encrypt(const Tox_Pass_Key *key, const uint8_t *plaintext, size_t plaintext_len,
-                          uint8_t *ciphertext, Tox_Err_Encryption *error);
+bool tox_pass_key_encrypt(const Tox_Pass_Key *key, const uint8_t plaintext[], size_t plaintext_len,
+                          uint8_t ciphertext[/*! plaintext_len + TOX_PASS_ENCRYPTION_EXTRA_LENGTH */], Tox_Err_Encryption *error);
 
 /**
  * This is the inverse of tox_pass_key_encrypt, also using only keys produced by
  * tox_pass_key_derive or tox_pass_key_derive_with_salt.
  *
  * @param ciphertext A byte array of length `ciphertext_len`.
- * @param ciphertext_len The length of the cipher text array. At least TOX_PASS_ENCRYPTION_EXTRA_LENGTH.
+ * @param ciphertext_len The length of the cipher text array. At least
+ *   TOX_PASS_ENCRYPTION_EXTRA_LENGTH.
  * @param plaintext The plain text array to write the decrypted data to.
  *
  * @return true on success.
  */
-bool tox_pass_key_decrypt(const Tox_Pass_Key *key, const uint8_t *ciphertext, size_t ciphertext_len,
-                          uint8_t *plaintext, Tox_Err_Decryption *error);
+bool tox_pass_key_decrypt(const Tox_Pass_Key *key, const uint8_t ciphertext[], size_t ciphertext_len,
+                          uint8_t plaintext[/*! ciphertext_len - TOX_PASS_ENCRYPTION_EXTRA_LENGTH */], Tox_Err_Decryption *error);
 
 typedef enum Tox_Err_Get_Salt {
 
@@ -318,7 +313,6 @@ typedef enum Tox_Err_Get_Salt {
 
 } Tox_Err_Get_Salt;
 
-
 /**
  * Retrieves the salt used to encrypt the given data.
  *
@@ -326,7 +320,8 @@ typedef enum Tox_Err_Get_Salt {
  * produce the same key as was previously used. Any data encrypted with this
  * module can be used as input.
  *
- * The cipher text must be at least TOX_PASS_ENCRYPTION_EXTRA_LENGTH bytes in length.
+ * The cipher text must be at least TOX_PASS_ENCRYPTION_EXTRA_LENGTH bytes in
+ * length.
  * The salt must be TOX_PASS_SALT_LENGTH bytes in length.
  * If the passed byte arrays are smaller than required, the behaviour is
  * undefined.
@@ -338,7 +333,9 @@ typedef enum Tox_Err_Get_Salt {
  *
  * @return true on success.
  */
-bool tox_get_salt(const uint8_t *ciphertext, uint8_t *salt, Tox_Err_Get_Salt *error);
+bool tox_get_salt(
+    const uint8_t ciphertext[TOX_PASS_ENCRYPTION_EXTRA_LENGTH],
+    uint8_t salt[TOX_PASS_SALT_LENGTH], Tox_Err_Get_Salt *error);
 
 /**
  * Determines whether or not the given data is encrypted by this module.
@@ -354,11 +351,10 @@ bool tox_get_salt(const uint8_t *ciphertext, uint8_t *salt, Tox_Err_Get_Salt *er
  *
  * @return true if the data is encrypted by this module.
  */
-bool tox_is_data_encrypted(const uint8_t *data);
-
+bool tox_is_data_encrypted(const uint8_t data[TOX_PASS_ENCRYPTION_EXTRA_LENGTH]);
 
 #ifdef __cplusplus
-}
+} /* extern "C" */
 #endif
 
 //!TOKSTYLE-
@@ -370,4 +366,4 @@ typedef Tox_Err_Get_Salt TOX_ERR_GET_SALT;
 
 //!TOKSTYLE+
 
-#endif // C_TOXCORE_TOXENCRYPTSAVE_TOXENCRYPTSAVE_H
+#endif /* C_TOXCORE_TOXENCRYPTSAVE_TOXENCRYPTSAVE_H */
